A standardized address to load containers, directories, secrets, and other object types. Address format depends on the type, and is validated at type selection.
Summary
Functions
Load a container from the address.
Load a directory from the address.
Load a file from the address.
Load a git ref (branch, tag or commit) from the address.
Load a git repository from the address.
A unique identifier for this Address.
Load a secret from the address.
Load a service from the address.
Load a local socket from the address.
The address value
Types
Functions
@spec container(t()) :: Dagger.Container.t()
Load a container from the address.
@spec directory(t(), exclude: [String.t()], include: [String.t()], gitignore: boolean() | nil, no_cache: boolean() | nil ) :: Dagger.Directory.t()
Load a directory from the address.
@spec file(t(), exclude: [String.t()], include: [String.t()], gitignore: boolean() | nil, no_cache: boolean() | nil ) :: Dagger.File.t()
Load a file from the address.
@spec git_ref(t()) :: Dagger.GitRef.t()
Load a git ref (branch, tag or commit) from the address.
@spec git_repository(t()) :: Dagger.GitRepository.t()
Load a git repository from the address.
@spec id(t()) :: {:ok, Dagger.AddressID.t()} | {:error, term()}
A unique identifier for this Address.
@spec secret(t()) :: Dagger.Secret.t()
Load a secret from the address.
@spec service(t()) :: Dagger.Service.t()
Load a service from the address.
@spec socket(t()) :: Dagger.Socket.t()
Load a local socket from the address.
The address value