Dagger.Check (dagger v0.20.8)

Copy Markdown View Source

Dagger.Check

Summary

Functions

Whether the check completed

The description of the check

If the check failed, this is the error

A unique identifier for this Check.

Return the fully qualified name of the check

The original module in which the check has been defined

Whether the check passed

The path of the check within its module

An emoji representing the result of the check

Execute the check

Types

t()

@type t() :: %Dagger.Check{client: term(), query_builder: term()}

Functions

completed(check)

@spec completed(t()) :: {:ok, boolean()} | {:error, term()}

Whether the check completed

description(check)

@spec description(t()) :: {:ok, String.t()} | {:error, term()}

The description of the check

error(check)

@spec error(t()) :: Dagger.Error.t() | nil

If the check failed, this is the error

id(check)

@spec id(t()) :: {:ok, Dagger.CheckID.t()} | {:error, term()}

A unique identifier for this Check.

name(check)

@spec name(t()) :: {:ok, String.t()} | {:error, term()}

Return the fully qualified name of the check

original_module(check)

@spec original_module(t()) :: Dagger.Module.t()

The original module in which the check has been defined

passed(check)

@spec passed(t()) :: {:ok, boolean()} | {:error, term()}

Whether the check passed

path(check)

@spec path(t()) :: {:ok, [String.t()]} | {:error, term()}

The path of the check within its module

result_emoji(check)

@spec result_emoji(t()) :: {:ok, String.t()} | {:error, term()}

An emoji representing the result of the check

run(check)

@spec run(t()) :: t()

Execute the check