Dagger.DiffStat
Summary
Functions
Number of added lines for this path.
A unique identifier for this DiffStat.
Type of change.
Previous path of the file, set only for renames.
Path of the changed file or directory.
Number of removed lines for this path.
Types
Functions
Number of added lines for this path.
@spec id(t()) :: {:ok, Dagger.DiffStatID.t()} | {:error, term()}
A unique identifier for this DiffStat.
@spec kind(t()) :: {:ok, Dagger.DiffStatKind.t()} | {:error, term()}
Type of change.
Previous path of the file, set only for renames.
Path of the changed file or directory.
Number of removed lines for this path.