Dagger.Generator
Summary
Functions
The generated changeset from the last run
Whether the generator complete
Return the description of the generator
Whether changeset from the last generator run is empty or not
A unique identifier for this Generator.
Return the fully qualified name of the generator
The original module in which the generator has been defined
The path of the generator within its module
Execute the generator
Types
Functions
@spec changes(t()) :: Dagger.Changeset.t()
The generated changeset from the last run
Whether the generator complete
Return the description of the generator
Whether changeset from the last generator run is empty or not
@spec id(t()) :: {:ok, Dagger.GeneratorID.t()} | {:error, term()}
A unique identifier for this Generator.
Return the fully qualified name of the generator
@spec original_module(t()) :: Dagger.Module.t()
The original module in which the generator has been defined
The path of the generator within its module
Execute the generator