Dagger.GeneratorGroup
Summary
Functions
The combined changes from the last run of the generators
Whether the generated changeset from the last run is empty or not
A unique identifier for this GeneratorGroup.
Return a list of individual generators and their details
Execute all selected generators
Types
Functions
@spec changes(t(), [{:on_conflict, Dagger.ChangesetsMergeConflict.t() | nil}]) :: Dagger.Changeset.t()
The combined changes from the last run of the generators
If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed.
Set 'continueOnConflicts' flag to force to merge the changes in a 'last write wins' strategy.
Whether the generated changeset from the last run is empty or not
@spec id(t()) :: {:ok, Dagger.GeneratorGroupID.t()} | {:error, term()}
A unique identifier for this GeneratorGroup.
@spec list(t()) :: {:ok, [Dagger.Generator.t()]} | {:error, term()}
Return a list of individual generators and their details
Execute all selected generators