The GeneratorGroupID scalar type represents an identifier for an object of type GeneratorGroup.
Summary
Types
@type t() :: String.t()
The GeneratorGroupID scalar type represents an identifier for an object of type GeneratorGroup.
@type t() :: String.t()