Image healthcheck configuration.
Summary
Functions
Healthcheck command arguments.
A unique identifier for this HealthcheckConfig.
Interval between running healthcheck. Example:30s
The maximum number of consecutive failures before the container is marked as unhealthy. Example:3
Healthcheck command is a shell command.
StartInterval configures the duration between checks during the startup phase. Example:5s
StartPeriod allows for failures during this initial startup period which do not count towards maximum number of retries. Example:0s
Healthcheck timeout. Example:3s
Types
Functions
Healthcheck command arguments.
@spec id(t()) :: {:ok, Dagger.HealthcheckConfigID.t()} | {:error, term()}
A unique identifier for this HealthcheckConfig.
Interval between running healthcheck. Example:30s
The maximum number of consecutive failures before the container is marked as unhealthy. Example:3
Healthcheck command is a shell command.
StartInterval configures the duration between checks during the startup phase. Example:5s
StartPeriod allows for failures during this initial startup period which do not count towards maximum number of retries. Example:0s
Healthcheck timeout. Example:3s