Dagger.UpGroup (dagger v0.20.8)

Copy Markdown View Source

Dagger.UpGroup

Summary

Functions

A unique identifier for this UpGroup.

Return a list of individual services and their details

Execute all selected service functions

Types

t()

@type t() :: %Dagger.UpGroup{client: term(), query_builder: term()}

Functions

id(up_group)

@spec id(t()) :: {:ok, Dagger.UpGroupID.t()} | {:error, term()}

A unique identifier for this UpGroup.

list(up_group)

@spec list(t()) :: {:ok, [Dagger.Up.t()]} | {:error, term()}

Return a list of individual services and their details

run(up_group)

@spec run(t()) :: t()

Execute all selected service functions